/**
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance
* with the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package org.apache.tez.dag.app;

import org.apache.hadoop.yarn.util.Clock;

import java.util.Collection;
import java.util.LinkedList;

public class MockClock implements Clock {
  
  long time;
  Collection<MockClockListener> listeners = new LinkedList<>();

  public MockClock() {
    this(1000);
  }

  public MockClock(long initTime) {
    time = initTime;
  }

  @Override
  public long getTime() {
    return time;
  }
  
  public void incrementTime(long inc) {
    time += inc;
    for (MockClockListener listener : listeners) {
      listener.onTimeUpdated(time);
    }
  }

  public void register(MockClockListener listener) {
    listeners.add(listener);
  }

  public interface MockClockListener {
    void onTimeUpdated(long newTime);
  }
}
